==> kadu_1.0.orig.tar.bz2: kadu-1.0/plugins/gadu_protocol/translations/gadu_protocol_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Unable to connect, server has not been found</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please change your email in &quot;Change password / email&quot; window. Leave new password field blank.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect, server has returned unknown data</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect, connection break during reading</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect, connection break during writing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect, invalid password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect, error of negotiation TLS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Too many connection attempts with bad password!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect, servers are down</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connection broken</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connection timeout!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disconnection has occurred</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GaduAddAccountWidget</name>
    <message>
        <source>Gadu-Gadu number</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remember Password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Account Identity</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Select or enter the identity that will be associated with this account.&lt;/i&gt;&lt;/font&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add Account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Register Account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remind GG number</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remind Password</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GaduChatImageService</name>
    <message>
        <source>This image has %1 KiB and exceeds recommended maximum size of %2 KiB. Some clients may have trouble with too large images.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do you really want to send this image?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GaduChatService</name>
    <message>
        <source>Kadu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Message too long (%1 &gt;= %2)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GaduContactPersonalInfoWidget</name>
    <message>
        <source>First Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Last Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Nickname</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gender</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Birthdate</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>City</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>State/Province</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>IP Address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Port</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>DNS Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Protocol Version</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Female</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Male</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GaduEditAccountWidget</name>
    <message>
        <source>Apply</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gadu-Gadu number</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remember password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Account Identity</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Select or enter the identity that will be associated with this account.&lt;/i&gt;&lt;/font&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Personal info</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Buddies</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connection</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Options</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Use default servers</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Use encrypted connection</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remove account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>External port</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You have to compile libgadu with SSL support to be able to enable encrypted connection</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Proxy configuration</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Images</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Receive images also when I am Invisible</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Warn me when the image being sent may be too large</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Some clients may have trouble with too large images (over 256 KiB).</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show my status only to buddies on my list</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>When disabled, anyone can see your status.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable composing events</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Your interlocutor will be notified when you are typing a message, before it is sent. And vice versa.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Block links from anonymous buddies</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Protects you from potentially malicious links in messages from anonymous buddies</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gadu-Gadu Server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Custom server IP addresses</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable file transfers</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>External IP</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Confrim Account Removal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure do you want to remove account %1 (%2)?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Status Visibility</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You are going to reveal your status to several buddies which are currently not allowed to see it.
Are you sure to allow them to know you are available?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Make my status visible anyway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Stay with private status</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remind GG number</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remind Password</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GaduPersonalInfoWidget</name>
    <message>
        <source>Unknown Gender</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Male</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Female</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Nick</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>First name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Last name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sex</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Family name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Birth year</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>City</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Family city</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GaduProtocol</name>
    <message>
        <source>Kadu</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GaduProtocolFactory</name>
    <message>
        <source>Gadu-Gadu number:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GaduProtocolPlugin</name>
    <message>
        <source>Gadu-Gadu Protocol</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cannot load Gadu-Gadu Protocol plugin. Please compile libgadu with zlib support.</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> kadu_3.0.orig.tar.bz2: kadu-3.0/plugins/gadu_protocol/translations/gadu_protocol_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Unable to connect, server has not been found</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please change your email in &quot;Change password / email&quot; window. Leave new password field blank.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect, server has returned unknown data</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect, connection break during reading</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect, connection break during writing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect, invalid password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect, error of negotiation TLS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Too many connection attempts with bad password!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect, servers are down</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connection broken</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connection timeout!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disconnection has occurred</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GaduAddAccountWidget</name>
    <message>
        <source>Gadu-Gadu number</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remember Password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Account Identity</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Select or enter the identity that will be associated with this account.&lt;/i&gt;&lt;/font&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add Account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Register Account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remind GG number</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remind Password</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GaduChatImageService</name>
    <message>
        <source>This image has %1 KiB and exceeds recommended maximum size of %2 KiB. Some clients may have trouble with too large images.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do you really want to send this image?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GaduChatService</name>
    <message>
        <source>Kadu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Message too long (%1 &gt;= %2)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GaduContactPersonalInfoWidget</name>
    <message>
        <source>First Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Last Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Nickname</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gender</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Birthdate</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>City</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>State/Province</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Female</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Male</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GaduEditAccountWidget</name>
    <message>
        <source>Apply</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gadu-Gadu number</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remember password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Account Identity</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Select or enter the identity that will be associated with this account.&lt;/i&gt;&lt;/font&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Personal info</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Buddies</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connection</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Options</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Use default servers</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Use encrypted connection</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remove account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You have to compile libgadu with SSL support to be able to enable encrypted connection</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Proxy configuration</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Images</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Receive images also when I am Invisible</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Warn me when the image being sent may be too large</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Some clients may have trouble with too large images (over 256 KiB).</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show my status only to buddies on my list</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>When disabled, anyone can see your status.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable composing events</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Your interlocutor will be notified when you are typing a message, before it is sent. And vice versa.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Block links from anonymous buddies</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Protects you from potentially malicious links in messages from anonymous buddies</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gadu-Gadu Server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Custom server IP addresses</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Confrim Account Removal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure do you want to remove account %1 (%2)?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Status Visibility</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You are going to reveal your status to several buddies which are currently not allowed to see it.
Are you sure to allow them to know you are available?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Make my status visible anyway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Stay with private status</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remind GG number</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remind Password</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GaduFileTransferService</name>
    <message>
        <source>Connect before sending files.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable SSL in account configuration and reconnect before sending files.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to login to GG Drive. Reconnect before sending files.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GaduOutgoingFileTransferHandler</name>
    <message>
        <source>Valid GG Drive ticket not available</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GaduPersonalInfoWidget</name>
    <message>
        <source>Unknown Gender</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Male</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Female</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Nick</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>First name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Last name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sex</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Family name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Birth year</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>City</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Family city</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GaduProtocol</name>
    <message>
        <source>Kadu</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GaduProtocolFactory</name>
    <message>
        <source>Gadu-Gadu number:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GaduProtocolPlugin</name>
    <message>
        <source>Gadu-Gadu Protocol</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cannot load Gadu-Gadu Protocol plugin. Please compile libgadu with zlib support.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GaduSendGiftAction</name>
    <message>
        <source>Send Gift...</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GaduUrlIncomingFileTransferHandler</name>
    <message>
        <source>Network error: %1</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
